#!/bin/bash

# Helper function for easy sed usage
function sedeasy {
    # Use sed -i '' for BSD systems
    sed -i "s/$(echo $1 | sed -e 's/\([[\/.*]\|\]\)/\\&/g')/$(echo $2 | sed -e 's/[\/&]/\\&/g')/g" $3
}

# Move working directory to path of this bash script
cd $(dirname "$0")

# Download wordpress to /tmp/ folder
echo "Download latest nl_NL wordpress"
curl -s https://nl.wordpress.org/latest-nl_NL.tar.gz > /tmp/wordpress-latest.tar.gz

# Extract Wordpress here
tar -xvzf /tmp/wordpress-latest.tar.gz wordpress

# Move wordpress files to current working root
mv wordpress/* .
rm -rf wordpress

# Install WP Cli
curl https://raw.githubusercontent.com/wp-cli/builds/gh-pages/phar/wp-cli.phar > wp
chmod +x wp

# Setup wp-config
mv wp-config-sample.php wp-config.php

echo 'Domain name:'
read domain_name

echo 'Site title:'
read site_title

echo 'Database name:'
read db_name

echo 'Database username:'
read db_user

echo 'Database password:'
read -s db_pass

echo 'Database host:'
read db_host

# Setup right DB settings
sedeasy localhost $db_host wp-config.php
sedeasy database_name_here $db_name wp-config.php
sedeasy username_here $db_user wp-config.php
sedeasy password_here $db_pass wp-config.php

# Setup Wordpress secret keys
SALT=$(curl -L https://api.wordpress.org/secret-key/1.1/salt/)
STRING='put your unique phrase here'
printf '%s\n' "g/$STRING/d" a "$SALT" . w | ed -s wp-config.php

# Convert Windows line endings to *nix style
sed -i '' 's/\r//g' wp-config.php

# Setup template
git clone https://code.bij1.org/bij1/wp-theme-simple-campaign.git tmp
rm -rf wp-content/themes/twenty*
mv tmp/src wp-content/themes/simple-campaign
rm -rf tmp/

echo "Installing Wordpress, please note down the password"
./wp core install --url=$domain_name --title=$site_title --admin_name=bij1admin --admin_email=ict@bij1.org --allow-root
echo -e "\n\n\n"

echo "Installing plugins"

function install_zipped_ext {
	# work-around for timeout issues during download
	echo "install_zipped_ext $@"
	name="$1"
	url="$2"

	filename=$(mktemp)

	curl -L --output $filename $url
	unzip -q $filename

	dirname=$(find -maxdepth 1 -name "${name}*" -type d)
	dirname=$(basename $dirname)

	[ "$dirname" = "$name" ] || mv -v $dirname $name
    zip -r $name.zip $name
    ./wp plugin install $name.zip --activate --allow-root
}

./wp plugin install advanced-custom-fields                      --activate --allow-root
# ./wp plugin install acf.zip                                     --activate --allow-root
# ./wp plugin install https://gitlab.com/wordpress-premium/advanced-custom-fields-pro/-/archive/v6.2.0/advanced-custom-fields-pro-v6.2.0.zip --activate --allow-root
./wp plugin install add-on-cf7-for-airtable                     --activate --allow-root
./wp plugin install cf7-to-zapier                               --activate --allow-root
./wp plugin install coming-soon                                 --activate --allow-root
./wp plugin install cf7-conditional-fields                      --activate --allow-root
./wp plugin install contact-form-7                              --activate --allow-root
./wp plugin install contact-form-7-dynamic-text-extension       --activate --allow-root
./wp plugin install contact-form-7-civicrm-integration          --activate --allow-root
./wp plugin install wp-gdpr-compliance                          --activate --allow-root
./wp plugin install doneren-met-mollie                          --activate --allow-root
./wp plugin install doi-helper                                  --activate --allow-root
./wp plugin install email-verification-for-contact-form-7       --activate --allow-root
./wp plugin install https://github.com/pronamic/gravityforms/releases/download/2.7.15/gravityforms-2.7.15.zip --activate --allow-root
./wp plugin install https://github.com/pronamic/wp-gravityforms-nl/releases/download/v3.0.7/gravityforms-nl.3.0.7.zip --activate --allow-root
./wp plugin install header-footer                               --activate --allow-root
./wp plugin install pronamic-ideal                              --activate --allow-root # https://github.com/pronamic/wp-pronamic-pay
./wp plugin install pronamic-pay-with-mollie-for-contact-form-7 --activate --allow-root
./wp plugin install wp-2fa                                      --activate --allow-root
./wp plugin install wp-crontrol                                 --activate --allow-root
./wp plugin install wordpress-seo                               --activate --allow-root
# ./wp plugin install gravityformsgutenberg                       --activate --allow-root

install_zipped_ext gravityformsmailchimp https://github.com/wp-premium/gravityformsmailchimp/archive/refs/tags/2.4.5.zip
install_zipped_ext gravityformswebhooks https://github.com/wp-premium/gravityformswebhooks/archive/refs/tags/1.4.zip
install_zipped_ext gravityformszapier https://github.com/wp-premium/gravityformszapier/archive/refs/tags/3.3.zip

echo "Activate BIJ1 theme"
./wp theme activate simple-campaign --allow-root
